@@ -1,13 +1,13 @@
 ##
-#' @title Compute summary statistic for groupings of units using given  method (typically, mean)
+#' @title Compute summary statistic for groupings of units using given method (typically, mean)
 #'
 #' @description Computes summary statistics for groupings (given as vector) of units in ena data using given method (typically, mean); computes summary statistic for point locations and edge weights for each grouping
 #'
 #' @export
 #'
-#' @param enaset An \code{\link{ENAset}} (optional)
+#' @param enaset An \code{\link{ENAset}} or a vector of values to group.
 #' @param by A vector of values the same length as units. Uses rotated points for group positions and normed data to get the group edge weights
-#' @param method A function that is used on grouped points. Default: mean()
+#' @param method A function that is used on grouped points. Default: mean().  If `enaset` is an ENAset, enaset$points.rotated will be groups using `mean` regardless of `method` provided
 #'
 #' @keywords ENA, set, group
 #'
@@ -39,18 +39,20 @@ ena.group <- function(
   by = NULL, #Vector of values  the same length as units.
   method = mean  #method by which to form groups from specified attribute/vector of values
 ) {
-  run.method = function(pts) {
+  run.method = function(pts, m = method) {
     points.dt = data.table::data.table(pts);
     if(is.logical(by)) {
-      points.dt.means = points.dt[by, lapply(.SD,method),]; # by=by];
+      points.dt.means = points.dt[by, lapply(.SD, m),]; # by=by];
     } else if(all(by %in% colnames(pts))) {
-      points.dt.means = points.dt[, lapply(.SD,method), by=by];
+      points.dt.means = points.dt[, lapply(.SD, m), by=by];
     } else {
-      points.dt.means = as.data.frame(aggregate(points.dt, by = list(by), FUN = method)) #"mean"))
+      points.dt.means = as.data.frame(aggregate(points.dt, by = list(by), FUN = m)) #"mean"))
       rownames(points.dt.means) = points.dt.means$Group.1
       points.dt.means = points.dt.means[,colnames(points.dt)]
       # agg.df[as.vector(unique(group.by)),]u
-      return (points.dt.means[as.vector(unique(by)),]);
+      # return (points.dt.means[as.vector(unique(by)),]);
+      points.dt.means[['ENA_GROUP_NAME']] = rownames(points.dt.means)
+      return(points.dt.means[which(rownames(points.dt.means) %in% unique(by)),])
     }
     return(as.data.frame(points.dt.means[,colnames(points.dt),with=F]))
   }
@@ -62,7 +64,7 @@ ena.group <- function(
   if("ENAset" %in% class(enaset)) {
     return(list(
       "names" = as.vector(unique(by)),
-      "points" = run.method(enaset$points.rotated),
+      "points" = run.method(enaset$points.rotated, m = mean),
       "line.weights" = run.method(enaset$line.weights)
     ));
   } else {
